@@ -14,6 +14,12 @@
  *                                                                         *
  ***************************************************************************/
 
+// force to use QT with STL
+#if defined(QT_NO_STL)
+# define DISABLE_QT_NO_STL
+# undef QT_NO_STL
+#endif
+
 #include "rtf2html.h"
 #include "rtf_table.h"
 #include "rtf_tools.h"
@@ -529,3 +535,8 @@ TQString RTF2HTML::toHTML() const {
    return html;
 }
 
+// restore QT_NO_STL
+#if defined(DISABLE_QT_NO_STL)
+# undef DISABLE_QT_NO_STL
+# define QT_NO_STL
+#endif
